__title__ = "zyx_tools"
__description__ = "tool"
__url__ = ""
__version__ = "0.0.9"
__author__ = "yuxin.zhang"
__author_email__ = "whyzi@qq.com"
__license__ = "MIT"
__copyright__ = "Copyright yuxin.zhang"
